#!/usr/bin/python

"Print the most representative packages in the system"

import gzip, math
freqs, local = {}, {}

# Read global frequency data
for line in gzip.GzipFile("popcon-frequencies.gz"):
	key, val = line[:-1].split(' ')
	freqs[key] = float(val)
docCount = freqs.pop('__NDOCS__')

# Read local popcon data
for line in open("/var/log/popularity-contest"):
	if line.startswith("POPULARITY"): continue
	if line.startswith("END-POPULARITY"): continue
	data = line[:-1].split(" ")
	if len(data) < 4: continue
	if data[3] == '<NOFILES>': # Empty/virtual packages
		local[data[2]] = 0.1
	elif len(data) == 4: # In use
		local[data[2]] = 1.
	elif data[4] == '<OLD>': # Unused
		local[data[2]] = 0.3
	elif data[4] == '<RECENT-CTIME>': # Recently installed
		local[data[2]] = 0.8

# TFIDF package scoring function
def score(pkg):
	if not pkg in freqs: return 0
	return local[pkg] * math.log(docCount / freqs[pkg])

# Output the sorted package list
for idx, pkg in enumerate(sorted(local.keys(), key=score, reverse=True)):
	print "%2d) %s" % (idx+1, pkg)
	if idx > 30: break
